<?php

namespace Drupal\chia\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;
use Drupal\chia\Entity\ChiaNodeInterface;
use Drupal\file\Entity\File;

/**
 * Defines the chianode entity type.
 *
 * @ConfigEntityType(
 *   id = "chia_node",
 *   label = @Translation("ChiaNode"),
 *   label_collection = @Translation("Nodes"),
 *   label_singular = @Translation("Chia node"),
 *   label_plural = @Translation("Chia nodes"),
 *   label_count = @PluralTranslation(
 *     singular = "@count chia node",
 *     plural = "@count chia nodes",
 *   ),
 *   handlers = {
 *     "list_builder" = "Drupal\chia\Controller\ChiaNodeListBuilder",
 *     "form" = {
 *       "add" = "Drupal\chia\Form\ChiaNodeForm",
 *       "edit" = "Drupal\chia\Form\ChiaNodeForm",
 *       "delete" = "Drupal\Core\Entity\EntityDeleteForm"
 *     }
 *   },
 *   config_prefix = "chia node",
 *   admin_permission = "administer chia nodes",
 *   links = {
 *     "collection" = "/admin/config/services/chia/chia-node",
 *     "add-form" = "/admin/config/services/chia/chia-node/add",
 *     "edit-form" = "/admin/config/services/chia/chia-node//{chia_node}",
 *     "delete-form" = "/admin/config/services/chia/chia-node/{chia_node}/delete"
 *   },
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label",
 *     "uuid" = "uuid"
 *   },
 *   config_export = {
 *     "id",
 *     "label",
 *     "description",
 *     "node_rpc_address",
 *     "node_is_public",
 *     "node_cert",
 *     "node_key",
 *   }
 * )
 */
class ChiaNode extends ConfigEntityBase implements ChiaNodeInterface, RpcInterface {

  /**
   * The chianode ID.
   *
   * @var string
   */
  protected $id;

  /**
   * The chianode label.
   *
   * @var string
   */
  protected $label;

  /**
   * The chianode status.
   *
   * @var bool
   */
  protected $status;

  /**
   * The chia_node description.
   *
   * @var string
   */
  protected $description;

  /**
   * @var string
   */
  protected $node_rpc_address;

  /**
   * @var bool
   */
  protected $node_is_public;

  /**
   * @var string
   */
  protected $node_cert;

  /**
   * @var string
   */
  protected $node_key;

  /**
   * @return mixed
   */
  public function getNodeRpcAddress(): ?string
  {
    return $this->node_rpc_address;
  }

  public function getRpcAddress(): ?string {
    return $this->getNodeRpcAddress();
  }

  /**
   * @param mixed $node_rpc_address
   */
  public function setNodeRpcAddress($node_rpc_address): void
  {
    $this->node_rpc_address = $node_rpc_address;
  }

  /**
   * @return int
   */
  public function getNodeCert(): ?int
  {
    return isset($this->node_cert) ? $this->node_cert[0] : null ;
  }

  public function getNodeCertPath(): ?string {
    $file = File::load($this->getNodeCert());
    return $file ? $file->getFileUri() : null;
  }

  public function getNodeKeyPath(): ?string {
    $file = File::load($this->getNodeKey());
    return $file ? $file->getFileUri() : null;
  }


  /**
   * @return int
   */
  public function getNodeKey(): ?int
  {
    return isset($this->node_key) ? $this->node_key[0] : null ;
  }
}
